@@ -57,7 +57,7 @@ class VTRTokenizer(PreTrainedTokenizerBase):
     font: str = "~/Library/Fonts/NotoSansDisplay-Regular.ttf"
     model_input_names: List[str] = None
     special_tokens: Optional[Dict[str, np.ndarray]] = None
-    max_length: int = 25
+    max_length: Optional[int] = 25
 
     def __post_init__(self):
         if self.model_input_names is None:
